/*
	file automatically generated by make_test_files.pl
	Fri Jan 17 09:18:55 2003
*/

/*****************************************************************************
 *                                                                           *
 *          UNURAN -- Universal Non-Uniform Random number generator          *
 *                                                                           *
 *****************************************************************************/
    
/**
 ** Tests for DISTR_CONT
 **/
    
/*---------------------------------------------------------------------------*/
#include "testunuran.h"
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* global variables                                                          */

static FILE *TESTLOG;               /* test log file                         */
static FILE *UNURANLOG;             /* unuran log file                       */

static int test_ok = TRUE;          /* all tests ok (boolean)                */
static int n_tests_failed;          /* number of failed tests                */

/*---------------------------------------------------------------------------*/

void test_new( void );
void test_set( void );
void test_get( void );
void test_chg( void );
void test_init( void );
void test_reinit( void );
void test_sample( void );
void test_validate( void );

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par );

int unur_distr_cont_set_verify( UNUR_PAR *par, int );

/*---------------------------------------------------------------------------*/


/* prototypes */

#define COMPARE_SAMPLE_SIZE  (500)
#define VIOLATE_SAMPLE_SIZE   (20)

double pdf(double x, const UNUR_DISTR *distr);
double dpdf(double x, const UNUR_DISTR *distr);
double cdf(double x, const UNUR_DISTR *distr);
double hr(double x, const UNUR_DISTR *distr);





/*---------------------------------------------------------------------------*/

int main()
{ 
	/* open log file for unuran and set output stream for unuran messages */
	UNURANLOG = fopen( "t_distr_cont_unuran.log","w" );
	abort_if_NULL( stderr,-1, UNURANLOG );
	unur_set_stream( UNURANLOG );

	/* open log file for testing */
	TESTLOG = fopen( "t_distr_cont_test.log","w" );
	abort_if_NULL( stderr,-1, TESTLOG );

	/* write header into log file */
  	{
		time_t started;  
		fprintf(TESTLOG,"\nUNURAN - Universal Non-Uniform RANdom number generator\n\n");
		if (time( &started ) != -1)
			fprintf(TESTLOG,"%s",ctime(&started));
		fprintf(TESTLOG,"\n====================================================\n\n");
	}

        /* seed build-in uniform generators */
        unur_urng_MRG31k3p_seed(358878);
	unur_urng_fish_seed(358878);
	unur_urng_mstd_seed(358878);

	/* seed uniform random number generator */
#if UNUR_URNG_TYPE == UNUR_URNG_PRNG
	unur_set_default_urng(prng_new("mt19937(358878)"));
#elif UNUR_URNG_TYPE == UNUR_URNG_RNGSTREAM
	{
	    unsigned long seed[6] = {358878,358878+1,358878+2,358878+3,358878+4,358878+5};
	    RngStream_SetPackageSeed(seed);
	}
#endif  /* UNUR_URNG_TYPE */

	/* set default debugging flag */
	unur_set_default_debug(UNUR_DEBUG_ALL);

	/* start test */
	printf("distr_cont: ");

	/* run tests */
	test_new();
	test_set();
	test_get();
	test_chg();
	test_init();
	test_sample();
	test_reinit();
	test_validate();

	/* test finished */
	printf("\n");  fflush(stdout);

	/* close log files */
	fprintf(TESTLOG,"\n====================================================\n\n");
	if (test_ok)
		fprintf(TESTLOG,"All tests PASSED.\n");
	else
		fprintf(TESTLOG,"Test(s) FAILED.\n");

	fclose(UNURANLOG);
	fclose(TESTLOG);

	/* free memory */
        compare_free_memory();

	/* exit */
	exit( (test_ok) ? 0 : -1 );

} /* end of main */

/*---------------------------------------------------------------------------*/

void test_new (void)
{
	/* start test */
	printf("[new "); fflush(stdout);
	fprintf(TESTLOG,"\n[new]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = new  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_new() */

/*---------------------------------------------------------------------------*/

void test_set (void)
{
	/* start test */
	printf("[set "); fflush(stdout);
	fprintf(TESTLOG,"\n[set]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_DISTR *distr = NULL;
   distr = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 36, (unur_distr_cont_set_pdf( distr, pdf )) );
n_tests_failed += check_errorcode( TESTLOG, 36, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 39, (unur_distr_cont_set_dpdf( distr, dpdf )) );
n_tests_failed += check_errorcode( TESTLOG, 39, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 42, (unur_distr_cont_set_cdf( distr, cdf )) );
n_tests_failed += check_errorcode( TESTLOG, 42, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 45, (unur_distr_cont_set_hr( distr, hr )) );
n_tests_failed += check_errorcode( TESTLOG, 45, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 48, (unur_distr_cont_set_pdfstr( distr, "pdf" )) );
n_tests_failed += check_errorcode( TESTLOG, 48, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 51, (unur_distr_cont_set_cdfstr( distr, "cdf" )) );
n_tests_failed += check_errorcode( TESTLOG, 51, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 54, (unur_distr_cont_set_hrstr( distr, "hr" )) );
n_tests_failed += check_errorcode( TESTLOG, 54, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 57, (unur_distr_cont_set_pdfparams( distr, NULL, 0 )) );
n_tests_failed += check_errorcode( TESTLOG, 57, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 60, (unur_distr_cont_set_domain( distr, 0., 1. )) );
n_tests_failed += check_errorcode( TESTLOG, 60, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 63, (unur_distr_cont_set_mode( distr, 0. )) );
n_tests_failed += check_errorcode( TESTLOG, 63, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 66, (unur_distr_cont_set_pdfarea( distr, 1. )) );
n_tests_failed += check_errorcode( TESTLOG, 66, UNUR_ERR_NULL );
unur_distr_free(distr);
}

/* invalid distribution type */
{
UNUR_DISTR *distr = NULL;
	distr = unur_distr_discr_new(); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 73, (unur_distr_cont_set_pdf( distr, pdf )) );
n_tests_failed += check_errorcode( TESTLOG, 73, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 76, (unur_distr_cont_set_dpdf( distr, dpdf )) );
n_tests_failed += check_errorcode( TESTLOG, 76, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 79, (unur_distr_cont_set_cdf( distr, cdf )) );
n_tests_failed += check_errorcode( TESTLOG, 79, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 82, (unur_distr_cont_set_hr( distr, hr )) );
n_tests_failed += check_errorcode( TESTLOG, 82, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 85, (unur_distr_cont_set_pdfstr( distr, "exp(-x)" )) );
n_tests_failed += check_errorcode( TESTLOG, 85, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 88, (unur_distr_cont_set_cdfstr( distr, "exp(-x)" )) );
n_tests_failed += check_errorcode( TESTLOG, 88, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 91, (unur_distr_cont_set_hrstr( distr, "exp(-x)" )) );
n_tests_failed += check_errorcode( TESTLOG, 91, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 94, (unur_distr_cont_set_pdfparams( distr, NULL, 0 )) );
n_tests_failed += check_errorcode( TESTLOG, 94, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 97, (unur_distr_cont_set_domain( distr, 0., 1. )) );
n_tests_failed += check_errorcode( TESTLOG, 97, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 100, (unur_distr_cont_set_mode( distr, 0. )) );
n_tests_failed += check_errorcode( TESTLOG, 100, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 103, (unur_distr_cont_set_pdfarea( distr, 1. )) );
n_tests_failed += check_errorcode( TESTLOG, 103, UNUR_ERR_DISTR_INVALID );
unur_distr_free(distr);
}

/* invalid NULL ptr */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_cont_new(); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 110, (unur_distr_cont_set_pdf( distr, NULL )) );
n_tests_failed += check_errorcode( TESTLOG, 110, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 113, (unur_distr_cont_set_dpdf( distr, NULL )) );
n_tests_failed += check_errorcode( TESTLOG, 113, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 116, (unur_distr_cont_set_cdf( distr, NULL )) );
n_tests_failed += check_errorcode( TESTLOG, 116, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 119, (unur_distr_cont_set_hr( distr, NULL )) );
n_tests_failed += check_errorcode( TESTLOG, 119, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 122, (unur_distr_cont_set_pdfstr( distr, NULL )) );
n_tests_failed += check_errorcode( TESTLOG, 122, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 125, (unur_distr_cont_set_cdfstr( distr, NULL )) );
n_tests_failed += check_errorcode( TESTLOG, 125, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 128, (unur_distr_cont_set_hrstr( distr, NULL )) );
n_tests_failed += check_errorcode( TESTLOG, 128, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 131, (unur_distr_cont_set_pdfparams( distr, NULL, 1 )) );
n_tests_failed += check_errorcode( TESTLOG, 131, UNUR_ERR_NULL );
unur_distr_free(distr);
}

/* invalid parameters */
{
UNUR_DISTR *distr = NULL;
   double pv[] = {1.,2.,3.};
   distr = unur_distr_cont_new(); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 139, (unur_distr_cont_set_pdfstr( distr, "" )) );
n_tests_failed += check_errorcode( TESTLOG, 139, UNUR_ERR_DISTR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 142, (unur_distr_cont_set_pdfstr( distr, "x * y * z" )) );
n_tests_failed += check_errorcode( TESTLOG, 142, UNUR_ERR_DISTR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 145, (unur_distr_cont_set_pdfstr( distr, "beta(2.)" )) );
n_tests_failed += check_errorcode( TESTLOG, 145, UNUR_ERR_DISTR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 148, (unur_distr_cont_set_cdfstr( distr, "" )) );
n_tests_failed += check_errorcode( TESTLOG, 148, UNUR_ERR_DISTR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 151, (unur_distr_cont_set_cdfstr( distr, "beta(2.)" )) );
n_tests_failed += check_errorcode( TESTLOG, 151, UNUR_ERR_DISTR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 154, (unur_distr_cont_set_hrstr( distr, "" )) );
n_tests_failed += check_errorcode( TESTLOG, 154, UNUR_ERR_DISTR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 157, (unur_distr_cont_set_pdfparams( distr, pv, -1 )) );
n_tests_failed += check_errorcode( TESTLOG, 157, UNUR_ERR_DISTR_NPARAMS );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 160, (unur_distr_cont_set_pdfparams( distr, pv, UNUR_DISTR_MAXPARAMS +1 )) );
n_tests_failed += check_errorcode( TESTLOG, 160, UNUR_ERR_DISTR_NPARAMS );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 163, (unur_distr_cont_set_domain( distr, 0., -1. )) );
n_tests_failed += check_errorcode( TESTLOG, 163, UNUR_ERR_DISTR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 166, (unur_distr_cont_set_pdfarea( distr, -1. )) );
n_tests_failed += check_errorcode( TESTLOG, 166, UNUR_ERR_DISTR_SET );
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = set  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_set() */

/*---------------------------------------------------------------------------*/

void test_get (void)
{
	/* start test */
	printf("[get "); fflush(stdout);
	fprintf(TESTLOG,"\n[get]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_DISTR *distr = NULL;
   double a, b;
   distr = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 179, ((void *) unur_distr_cont_get_pdf( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 179, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 182, ((void *) unur_distr_cont_get_dpdf( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 182, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 185, ((void *) unur_distr_cont_get_cdf( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 185, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 188, ((void *) unur_distr_cont_get_hr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 188, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 191, (unur_distr_cont_get_pdfstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 191, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 194, (unur_distr_cont_get_dpdfstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 194, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 197, (unur_distr_cont_get_cdfstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 197, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 200, (unur_distr_cont_get_hrstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 200, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 203, (unur_distr_cont_get_pdfparams( distr, NULL )) );
n_tests_failed += check_errorcode( TESTLOG, 203, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 206, (unur_distr_cont_get_domain( distr, &a, &b )) );
n_tests_failed += check_errorcode( TESTLOG, 206, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 209, (unur_distr_cont_get_mode( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 209, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 212, (unur_distr_cont_get_pdfarea( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 212, UNUR_ERR_NULL );
unur_distr_free(distr);
}

/* invalid distribution type */
{
UNUR_DISTR *distr = NULL;
   double a,b;
   distr = unur_distr_discr_new(); 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 220, ((void *) unur_distr_cont_get_pdf( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 220, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 223, ((void *) unur_distr_cont_get_dpdf( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 223, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 226, ((void *) unur_distr_cont_get_cdf( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 226, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 229, ((void *) unur_distr_cont_get_hr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 229, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 232, (unur_distr_cont_get_pdfstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 232, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 235, (unur_distr_cont_get_dpdfstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 235, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 238, (unur_distr_cont_get_cdfstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 238, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 241, (unur_distr_cont_get_hrstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 241, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 244, (unur_distr_cont_get_pdfparams( distr, NULL )) );
n_tests_failed += check_errorcode( TESTLOG, 244, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 247, (unur_distr_cont_get_domain( distr, &a, &b )) );
n_tests_failed += check_errorcode( TESTLOG, 247, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 250, (unur_distr_cont_get_mode( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 250, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 253, (unur_distr_cont_get_pdfarea( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 253, UNUR_ERR_DISTR_INVALID );
unur_distr_free(distr);
}

/* parameters not unknown */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_cont_new(); 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 260, (unur_distr_cont_get_pdfstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 260, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 263, (unur_distr_cont_get_dpdfstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 263, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 266, (unur_distr_cont_get_cdfstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 266, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 269, (unur_distr_cont_get_hrstr( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 269, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 272, (unur_distr_cont_get_mode( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 272, UNUR_ERR_DISTR_GET );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 275, (unur_distr_cont_get_pdfarea( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 275, UNUR_ERR_DISTR_GET );
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = get  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_get() */

/*---------------------------------------------------------------------------*/

void test_chg (void)
{
	/* start test */
	printf("[chg "); fflush(stdout);
	fprintf(TESTLOG,"\n[chg]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_DISTR *distr = NULL;
   distr = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 286, (unur_distr_cont_upd_mode( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 286, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 289, (unur_distr_cont_upd_pdfarea( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 289, UNUR_ERR_NULL );
unur_distr_free(distr);
}

/* invalid distribution type */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_discr_new(); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 296, (unur_distr_cont_upd_mode( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 296, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 299, (unur_distr_cont_upd_pdfarea( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 299, UNUR_ERR_DISTR_INVALID );
unur_distr_free(distr);
}

/* missing data */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_cont_new(); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 306, (unur_distr_cont_upd_mode( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 306, UNUR_ERR_DISTR_DATA );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 309, (unur_distr_cont_upd_pdfarea( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 309, UNUR_ERR_DISTR_DATA );
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = chg  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_chg() */

/*---------------------------------------------------------------------------*/

void test_init (void)
{
	/* start test */
	printf("[init "); fflush(stdout);
	fprintf(TESTLOG,"\n[init]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = init  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_init() */

/*---------------------------------------------------------------------------*/

void test_reinit (void)
{
	/* start test */
	printf("[reinit "); fflush(stdout);
	fprintf(TESTLOG,"\n[reinit]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = reinit  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_reinit() */

/*---------------------------------------------------------------------------*/

void test_sample (void)
{
	/* start test */
	printf("[sample "); fflush(stdout);
	fprintf(TESTLOG,"\n[sample]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_DISTR *distr = NULL;
   distr = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 328, (unur_distr_cont_eval_pdf( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 328, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 331, (unur_distr_cont_eval_dpdf( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 331, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 334, (unur_distr_cont_eval_cdf( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 334, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 337, (unur_distr_cont_eval_hr( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 337, UNUR_ERR_NULL );
unur_distr_free(distr);
}

/* invalid distribution object */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_discr_new(); 

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 344, (unur_distr_cont_eval_pdf( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 344, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 347, (unur_distr_cont_eval_dpdf( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 347, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 350, (unur_distr_cont_eval_cdf( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 350, UNUR_ERR_DISTR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 353, (unur_distr_cont_eval_hr( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 353, UNUR_ERR_DISTR_INVALID );
unur_distr_free(distr);
}

/* missing data */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_cont_new(); 

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 360, (unur_distr_cont_eval_pdf( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 360, UNUR_ERR_DISTR_DATA );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 363, (unur_distr_cont_eval_dpdf( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 363, UNUR_ERR_DISTR_DATA );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 366, (unur_distr_cont_eval_cdf( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 366, UNUR_ERR_DISTR_DATA );

unur_errno = 0;
n_tests_failed += check_expected_INFINITY( TESTLOG, 369, (unur_distr_cont_eval_hr( 1., distr )) );
n_tests_failed += check_errorcode( TESTLOG, 369, UNUR_ERR_DISTR_DATA );
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = sample  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_sample() */

/*---------------------------------------------------------------------------*/

void test_validate (void)
{
	UNUR_DISTR *distr[1];
	UNUR_PAR *par;
	UNUR_GEN *gen;
	int n_tests_failed = 0;
	double *darray;
	double fpm[10];

	/* start test */
	printf("[validate "); fflush(stdout);
	fprintf(TESTLOG,"\n[validate]\n");

	/* reset counter */
	n_tests_failed = 0;


/* distributions: 0 */

/* free distributions */
#if WITH_DMALLOC
	dmalloc_vmessage("section = validate  ================================\n","");
	dmalloc_log_unfreed();
#endif


	/* test finished */
	test_ok &= (n_tests_failed>2) ? 0 : 1;   /* we accept 2 failure */
	(n_tests_failed>2) ? printf(" --> failed] ") : printf(" --> ok] ");

	/* prevent compiler from making useless annoying warnings */
	distr[0] = NULL;
	par = NULL;
	gen = NULL;
	darray = NULL;
	fpm[0] = 0.;

} /* end of test_validate */

/*---------------------------------------------------------------------------*/


double pdf(double x, const UNUR_DISTR *distr) { return 1.; }
double dpdf(double x, const UNUR_DISTR *distr) { return 1.; }
double cdf(double x, const UNUR_DISTR *distr) { return 1.; }
double hr(double x, const UNUR_DISTR *distr) { return 1.; }



/*---------------------------------------------------------------------------*/
/* run generator in verifying mode */

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par )
{
	UNUR_GEN *gen;
	int i;

	/* switch to verifying mode */
	unur_distr_cont_set_verify(par,1);

	/* initialize generator */
	gen = unur_init( par ); abort_if_NULL(LOG, line, gen);

	/* run generator */
	for (i=0; i<VIOLATE_SAMPLE_SIZE; i++)
		unur_sample_cont(gen);

	/* destroy generator */
	unur_free(gen); 

} /* end of run_verify_generator() */

int unur_distr_cont_set_verify(UNUR_PAR *par, int verify) {return 0;}
